==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/dce/vehicle__widget_8h.js <==
var vehicle__widget_8h =
[
    [ "VehicleDetailsWidgets", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37", [
      [ "WID_VD_CAPTION", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a3de5469e616d208dabdb2d1e68a9de1b", null ],
      [ "WID_VD_RENAME_VEHICLE", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a012a5d431a6b312aa5912b6b9ed89eca", null ],
      [ "WID_VD_TOP_DETAILS", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37abaa561a0e2c04ea3f2ff734414ccce30", null ],
      [ "WID_VD_INCREASE_SERVICING_INTERVAL", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a74e962faa7a3c753e7554fb41b474758", null ],
      [ "WID_VD_DECREASE_SERVICING_INTERVAL", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a121455544cc8552915b930e59c2753d7", null ],
      [ "WID_VD_SERVICE_INTERVAL_DROPDOWN", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a44c5de42371721fcd24d1e5eb36ada76", null ],
      [ "WID_VD_SERVICING_INTERVAL", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a94fa401e3a76e680baa696f22024bbb1", null ],
      [ "WID_VD_MIDDLE_DETAILS", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37abcb72caf286cfa5db336cda99fb67b2f", null ],
      [ "WID_VD_MATRIX", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a7a0ee3684ec84cb191e3d7c894218c31", null ],
      [ "WID_VD_SCROLLBAR", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37ab1c1e1a89ed46952892ac48b224c832e", null ],
      [ "WID_VD_DETAILS_CARGO_CARRIED", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37af33967b79f7d2092eed71957399b8f9d", null ],
      [ "WID_VD_DETAILS_TRAIN_VEHICLES", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a992300f70a58a5975522930c8b418cd2", null ],
      [ "WID_VD_DETAILS_CAPACITY_OF_EACH", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37af2710c25d013cfab9b36376563ab9b48", null ],
      [ "WID_VD_DETAILS_TOTAL_CARGO", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37ab406184ad446e30018ece03540a0c624", null ]
    ] ],
    [ "VehicleListWidgets", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5", [
      [ "WID_VL_CAPTION", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5ac306f5b1a908abf0add20c8f012887c5", null ],
      [ "WID_VL_SORT_ORDER", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a7569e51d5a1040753778d232da501f72", null ],
      [ "WID_VL_SORT_BY_PULLDOWN", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a00fe76795949477567fb04af3ec811ce", null ],
      [ "WID_VL_LIST", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5ad1c9098a0ff2b5a6b20f0710b1ba4884", null ],
      [ "WID_VL_SCROLLBAR", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5ab99e5103f3c426897c9e2c2c8f5d00be", null ],
      [ "WID_VL_HIDE_BUTTONS", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a0ce5bb1f2611778d20e0d200d3d8db06", null ],
      [ "WID_VL_AVAILABLE_VEHICLES", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a1f482fa34b5d4cf1cdcae8b105fe1b47", null ],
      [ "WID_VL_MANAGE_VEHICLES_DROPDOWN", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a09f06a23728db94d83274c5b60f38591", null ],
      [ "WID_VL_STOP_ALL", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a506fa96050f69f22154ccc8a86d70622", null ],
      [ "WID_VL_START_ALL", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a03f834500b3f63e0e1e6094f25647220", null ]
    ] ],
    [ "VehicleRefitWidgets", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1", [
      [ "WID_VR_CAPTION", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1ad8bb2b7b4bb635e0bbc54a9d9eb18a6c", null ],
      [ "WID_VR_VEHICLE_PANEL_DISPLAY", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a479b55656c88a7fd7af79d157b83d858", null ],
      [ "WID_VR_SHOW_HSCROLLBAR", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a2923eae52364efd434e2942bbb6dbc71", null ],
      [ "WID_VR_HSCROLLBAR", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a4a2ba78ad2a8ca5329910e1961797407", null ],
      [ "WID_VR_SELECT_HEADER", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a97548441ca8681d8cd88c31a09844c67", null ],
      [ "WID_VR_MATRIX", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a1b6673d553f7b01184f7f1fdb085e627", null ],
      [ "WID_VR_SCROLLBAR", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a1dc81032218bdd3998eaa38ee2005033", null ],
      [ "WID_VR_INFO", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1ac0e31a16c64594c7c9189129466f73db", null ],
      [ "WID_VR_REFIT", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a6f95eb61ca42d1ab5bd2cea6a055ce07", null ]
    ] ],
    [ "VehicleViewWidgets", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfac", [
      [ "WID_VV_CAPTION", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca70d65eb0ff5a61202fe84eb5068c90ba", null ],
      [ "WID_VV_VIEWPORT", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfacaaf0188a4c138776db50da9852266e5b5", null ],
      [ "WID_VV_START_STOP", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca852b11c56de32bf300dcb3e02cd0e424", null ],
      [ "WID_VV_CENTER_MAIN_VIEW", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca7e2f5e4f0b2d0b137315b919a74f8486", null ],
      [ "WID_VV_GOTO_DEPOT", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca01567b07957f3e61a9e4651555fca6dc", null ],
      [ "WID_VV_REFIT", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca793328a4fde3f599d7db0808f03b6a67", null ],
      [ "WID_VV_SHOW_ORDERS", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca4a63e8164614c5db472c74a1a059062c", null ],
      [ "WID_VV_SHOW_DETAILS", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfacaa0c785e675796da4ffcecf4555105aa3", null ],
      [ "WID_VV_CLONE", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca56274d2d70161acaa7699d1b3bad794c", null ],
      [ "WID_VV_SELECT_DEPOT_CLONE", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca1987b31d1df95e16a944adef0c2dad9e", null ],
      [ "WID_VV_SELECT_REFIT_TURN", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca8b39d4fdfb21c66a56bdb01ee28c842e", null ],
      [ "WID_VV_TURN_AROUND", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca07a2278cbe2f7874d3e614658b282844", null ],
      [ "WID_VV_FORCE_PROCEED", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca232d95b920f6eed4a89167f3cd155a06", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/dce/vehicle__widget_8h.js <==
var vehicle__widget_8h =
[
    [ "VehicleDetailsWidgets", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37", [
      [ "WID_VD_CAPTION", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a3de5469e616d208dabdb2d1e68a9de1b", null ],
      [ "WID_VD_TOP_DETAILS", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37abaa561a0e2c04ea3f2ff734414ccce30", null ],
      [ "WID_VD_INCREASE_SERVICING_INTERVAL", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a74e962faa7a3c753e7554fb41b474758", null ],
      [ "WID_VD_DECREASE_SERVICING_INTERVAL", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a121455544cc8552915b930e59c2753d7", null ],
      [ "WID_VD_SERVICE_INTERVAL_DROPDOWN", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a44c5de42371721fcd24d1e5eb36ada76", null ],
      [ "WID_VD_SERVICING_INTERVAL", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a94fa401e3a76e680baa696f22024bbb1", null ],
      [ "WID_VD_MIDDLE_DETAILS", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37abcb72caf286cfa5db336cda99fb67b2f", null ],
      [ "WID_VD_MATRIX", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a7a0ee3684ec84cb191e3d7c894218c31", null ],
      [ "WID_VD_SCROLLBAR", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37ab1c1e1a89ed46952892ac48b224c832e", null ],
      [ "WID_VD_DETAILS_CARGO_CARRIED", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37af33967b79f7d2092eed71957399b8f9d", null ],
      [ "WID_VD_DETAILS_TRAIN_VEHICLES", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37a992300f70a58a5975522930c8b418cd2", null ],
      [ "WID_VD_DETAILS_CAPACITY_OF_EACH", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37af2710c25d013cfab9b36376563ab9b48", null ],
      [ "WID_VD_DETAILS_TOTAL_CARGO", "df/dce/vehicle__widget_8h.html#ab9c7067a20969552a4e8d2c6f54cce37ab406184ad446e30018ece03540a0c624", null ]
    ] ],
    [ "VehicleListWidgets", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5", [
      [ "WID_VL_CAPTION", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5ac306f5b1a908abf0add20c8f012887c5", null ],
      [ "WID_VL_GROUP_ORDER", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5aa10a8d900fc2fef6beb034b1b322157d", null ],
      [ "WID_VL_GROUP_BY_PULLDOWN", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a1ddb9068ae0fbe93d4821ad38cd7bbb6", null ],
      [ "WID_VL_SORT_ORDER", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a7569e51d5a1040753778d232da501f72", null ],
      [ "WID_VL_SORT_BY_PULLDOWN", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a00fe76795949477567fb04af3ec811ce", null ],
      [ "WID_VL_LIST", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5ad1c9098a0ff2b5a6b20f0710b1ba4884", null ],
      [ "WID_VL_SCROLLBAR", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5ab99e5103f3c426897c9e2c2c8f5d00be", null ],
      [ "WID_VL_HIDE_BUTTONS", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a0ce5bb1f2611778d20e0d200d3d8db06", null ],
      [ "WID_VL_AVAILABLE_VEHICLES", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a1f482fa34b5d4cf1cdcae8b105fe1b47", null ],
      [ "WID_VL_MANAGE_VEHICLES_DROPDOWN", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a09f06a23728db94d83274c5b60f38591", null ],
      [ "WID_VL_STOP_ALL", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a506fa96050f69f22154ccc8a86d70622", null ],
      [ "WID_VL_START_ALL", "df/dce/vehicle__widget_8h.html#a1307732f5a143334069025b9af99f7e5a03f834500b3f63e0e1e6094f25647220", null ]
    ] ],
    [ "VehicleRefitWidgets", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1", [
      [ "WID_VR_CAPTION", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1ad8bb2b7b4bb635e0bbc54a9d9eb18a6c", null ],
      [ "WID_VR_VEHICLE_PANEL_DISPLAY", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a479b55656c88a7fd7af79d157b83d858", null ],
      [ "WID_VR_SHOW_HSCROLLBAR", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a2923eae52364efd434e2942bbb6dbc71", null ],
      [ "WID_VR_HSCROLLBAR", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a4a2ba78ad2a8ca5329910e1961797407", null ],
      [ "WID_VR_SELECT_HEADER", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a97548441ca8681d8cd88c31a09844c67", null ],
      [ "WID_VR_MATRIX", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a1b6673d553f7b01184f7f1fdb085e627", null ],
      [ "WID_VR_SCROLLBAR", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a1dc81032218bdd3998eaa38ee2005033", null ],
      [ "WID_VR_INFO", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1ac0e31a16c64594c7c9189129466f73db", null ],
      [ "WID_VR_REFIT", "df/dce/vehicle__widget_8h.html#ae8d6ab8951551ba037c9f1039877f0c1a6f95eb61ca42d1ab5bd2cea6a055ce07", null ]
    ] ],
    [ "VehicleViewWidgets", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfac", [
      [ "WID_VV_CAPTION", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca70d65eb0ff5a61202fe84eb5068c90ba", null ],
      [ "WID_VV_VIEWPORT", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfacaaf0188a4c138776db50da9852266e5b5", null ],
      [ "WID_VV_START_STOP", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca852b11c56de32bf300dcb3e02cd0e424", null ],
      [ "WID_VV_RENAME", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca256e0ddf2c3c0d86a9f822563a41fa40", null ],
      [ "WID_VV_LOCATION", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca02b064f4630d01a73500851b2c749a8d", null ],
      [ "WID_VV_ORDER_LOCATION", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca33b04495e3aede21716118fb190ded7b", null ],
      [ "WID_VV_GOTO_DEPOT", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca01567b07957f3e61a9e4651555fca6dc", null ],
      [ "WID_VV_REFIT", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca793328a4fde3f599d7db0808f03b6a67", null ],
      [ "WID_VV_SHOW_ORDERS", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca4a63e8164614c5db472c74a1a059062c", null ],
      [ "WID_VV_SHOW_DETAILS", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfacaa0c785e675796da4ffcecf4555105aa3", null ],
      [ "WID_VV_CLONE", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca56274d2d70161acaa7699d1b3bad794c", null ],
      [ "WID_VV_SELECT_DEPOT_CLONE", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca1987b31d1df95e16a944adef0c2dad9e", null ],
      [ "WID_VV_SELECT_REFIT_TURN", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca8b39d4fdfb21c66a56bdb01ee28c842e", null ],
      [ "WID_VV_TURN_AROUND", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca07a2278cbe2f7874d3e614658b282844", null ],
      [ "WID_VV_FORCE_PROCEED", "df/dce/vehicle__widget_8h.html#a9bcabe05412962349edc925b6246dfaca232d95b920f6eed4a89167f3cd155a06", null ]
    ] ]
];
